Skip to contents

A class extending the Workspace class with additional information for the IQB Testcenter. It can be created by the function access_workspace() after login_testcenter().

Slots

login

LoginTestcenter. Login information for the IQB Testcenter.

ws_id

ID of the workspace. The workspace ID can also be found in the workspace URL.

ws_label

Label of the workspace.