Add metadata to units
add_metadata.RdThis function adds the unit metadata for a unit table generated by calling get_units(). Please note that no other operation except for filtering or add_coding_scheme() should be applied to the units.
Metadata fields remain list-columns if any of the selected workspace profiles
allow multiple values for that field, including in workspaces allowing only one value.
Arguments
- units
Tibble holding units retrieved from
get_units().