List booklet files
list_booklets.RdThis function serves as a wrapper for list_files().
Arguments
- workspace
WorkspaceTestcenter. Workspace information necessary to retrieve booklet list from the API.

list_booklets.RdThis function serves as a wrapper for list_files().
WorkspaceTestcenter. Workspace information necessary to retrieve booklet list from the API.