Skip to contents

[Experimental]

This function returns the responses in a format where the values are still list columns that need to be unpacked.

Usage

prepare_coded(responses)

Arguments

responses

Tibble. Responses retrieved from the IQB Testcenter via get_responses() or from an extracted csv and read via read_responses(). It can be used for data gathered by the StarS player.

Value

A tibble.