Workspace access for IQB Testcenter
WorkspaceTestcenter-class.RdA class extending the Workspace class with additional information for the IQB Testcenter. It can be created by the function access_workspace() after login_testcenter().
Slots
loginLoginTestcenter. Login information for the IQB Testcenter.
ws_idID of the workspace. The workspace ID can also be found in the workspace URL.
ws_labelLabel of the workspace.