Code unit responses with coding schemes
code_responses.RdThis function automatically codes responses by using the eatAutoCode
package. It is prepared for the response format returned by get_responses()
and read_responses(). Rows with responses = NA are removed before coding
schemes are prepared and are not sent to the auto-coder; they represent units
with no stored response payload and are left for complete_design() to
classify against the full test design.
Usage
code_responses(
responses,
units,
prepare = FALSE,
overwrite = FALSE,
codes_manual = NULL,
missings = NULL
)Arguments
- responses
Tibble. Response data retrieved from the IQB Testcenter with setting the argument
prepare = FALSEforget_responses()orread_responses().- units
Tibble. Unit data retrieved from the IQB Studio with
get_units().- prepare
Logical. Whether to unpack the coding results and to add information from the coding schemes.
- overwrite
Logical. Should column
unit_codesbe overwritten if they exist onunits. Defaults toFALSE, i.e.,unit_codeswill be used if they were added tounitsbeforehand by applyingadd_coding_schemes().- codes_manual
Tibble (optional). Data frame holding the manual codes. Defaults to
NULLand does only automatic coding.- missings
Tibble (optional). Provide missing meta data with
code_id,code_status,code_score, andcode_type. Defaults toNULLand uses default scheme.