Complete design with coded responses
complete_design.RdThis function automatically completes missings for coded responses.
Usage
complete_design(
coded,
units,
design,
identifiers = c("group_id", "login_name", "login_code"),
overwrite = FALSE,
missings = NULL,
recode_omissions_to_not_reached = FALSE
)Arguments
- coded
Tibble. Response data coded with
code_responses(). The argumentpreparemust beTRUE.- units
Tibble. Unit data retrieved from the IQB Studio after setting the argument
unit_definition = TRUEforget_units()– otherwise the page order of variables could not be correctly inferred from the variable source tree. Could already be treated byadd_coding_scheme()to save some time.- design
Tibble. Design retrieved from Testcenter via
get_design()or an object formatted in the same way.- identifiers
Character. Contains person identifiers of the dataset
coded. Defaults toc("group_id", "login_name", "login_code")which corresponds to the identifiers of the IQB Testcenter.- overwrite
Logical. Should column
unit_codesbe overwritten if they exist onunits. Defaults toFALSE, i.e.,unit_codeswill be used if they were added tounitsbeforehand by applyingadd_coding_schemes().- missings
Tibble (optional). Provide missing meta data with
code_id,code_status,code_score, andcode_type. Defaults toNULLand uses default scheme. (Currently, only one missing scheme is supported.)- recode_omissions_to_not_reached
Logical. Should trailing omissions (
MISSING_BY_OMISSION) be recoded to not reached (MISSING_NOT_REACHED) when they occur at the end of a booklet? Defaults toFALSE.