Generates booklet XMLs from booklet, testlet, and unit information
generate_booklets.RdPlease note that the function currently only works for units that are nested within
Usage
generate_booklets(
booklets,
app_version = "16.0.2",
login = NULL,
booklet_config_version = c("18.0", "legacy-16")
)Arguments
- booklets
Must be a tibble with the columns
booklet_id,booklet_label, andbooklet_units.Optionally, the columnsbooklet_description(character) andbooklet_configuration(list) can be added. The (list) columnbooklet_unitsis a nested tibble with columnstestlet_id,testlet_label, andunits. Optionally, it can contain the columnstestlet_restrictionsandtestlets. Finally, the (list) columnunitsis again a nested tibble with columnsunit_key,unit_alias,unit_label, andunit_labelshort. The optionaltestletscolumn can contain nested tibbles with the same structure asbooklet_units.- app_version
Version of the target Testcenter instance. Defaults to
"16.0.0".- login
Target Testcenter instance. If it is available, the
app_versionwill be overwritten.- booklet_config_version
Booklet configuration version.
"18.0"emits the current Testcenter booklet configuration keys."legacy-16"emits the legacy key set used by older Testcenter 16 workflows.