Summarise LOADCOMPLETE environment logs
summarise_log_environment.RdExtracts browser, operating system, device, screen size, orientation, and
initial LOADCOMPLETE load time. Multiple LOADCOMPLETE rows per session
are retained as diagnostics via count and conflict columns while the first
non-missing value per field is returned. Sessions without LOADCOMPLETE
are retained with zero event counts and missing environment fields.
Arguments
- logs
Tibble. Logs retrieved with
get_logs()or read withread_logs().- session_cols
Optional character vector with columns defining a test session. By default, all available columns among
group_id,login_name,login_code, andbooklet_idare used.