Summarise focus state logs
summarise_log_focus.RdSummarises raw FOCUS events per session. Durations are computed from the
first FOCUS = HAS_NOT in a focus-loss interval until the next raw
FOCUS = HAS event. Repeated HAS_NOT events before regain are counted
separately but do not shorten the interval.
Arguments
- logs
Tibble. Logs retrieved with
get_logs()or read withread_logs().- session_cols
Optional character vector with columns defining a test session. By default, all available session columns are used.
- focus_loss_threshold_ms
Numeric. Focus losses longer than this threshold are counted as very long focus losses.