Summarise log event types
summarise_log_inventory.RdCounts log event types and classifies whether an event type is known from Testcenter logging and whether eatPrepTBA currently has a parser for it. This function is intended as a cheap first diagnostic before parsing large log data in detail.
Arguments
- logs
Tibble. Logs retrieved with
get_logs()or read withread_logs().