Summarise page state logs
summarise_log_pages.RdSummarises raw CURRENT_PAGE_ID, CURRENT_PAGE_NR, and PAGE_COUNT events
per session/unit. reached_last_page_nr only checks whether the maximum
observed page number reached the reported page count. observed_pages_complete
is stricter and is only TRUE when all integer page numbers from 1 to
PAGE_COUNT were observed and the page count was consistent; otherwise it is
FALSE for visible gaps or NA when completeness cannot be judged.
Arguments
- logs
Tibble. Logs retrieved with
get_logs()or read withread_logs().- session_cols
Optional character vector with columns defining a test session. By default, all available session columns are used.
- unit_cols
Optional character vector with columns defining units. By default, available columns among
unit_keyandunit_aliasare used.